Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender-addons.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorMartin Poirier <theeth@yahoo.com>2012-02-12 23:32:24 +0400
committerMartin Poirier <theeth@yahoo.com>2012-02-12 23:32:24 +0400
commita6d7d6c040ff61c7b894cb374ded7c5d450290c2 (patch)
treeef6df78ba1c5b2bcaa1294faa11e6a23d62756c8 /netrender/slave.py
parenta4683ac1a4f0e3ff23573dff1c9d739e6d46ac69 (diff)
netrender
change to the repatching and local naming algorithms to better support different files with same name and dependency folder hierarchies.
Diffstat (limited to 'netrender/slave.py')
-rw-r--r--netrender/slave.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/netrender/slave.py b/netrender/slave.py
index ea132df2..fe3979a7 100644
--- a/netrender/slave.py
+++ b/netrender/slave.py
@@ -59,7 +59,7 @@ def testCancel(conn, job_id, frame_number):
return False
def testFile(conn, job_id, slave_id, rfile, JOB_PREFIX, main_path=None):
- job_full_path = prefixPath(JOB_PREFIX, rfile.filepath, main_path, force=rfile.force)
+ job_full_path = createLocalPath(rfile, JOB_PREFIX, main_path, rfile.force)
found = os.path.exists(job_full_path)
@@ -73,7 +73,7 @@ def testFile(conn, job_id, slave_id, rfile, JOB_PREFIX, main_path=None):
if not found:
# Force prefix path if not found
- job_full_path = prefixPath(JOB_PREFIX, rfile.filepath, main_path, force=True)
+ job_full_path = createLocalPath(rfile, JOB_PREFIX, main_path, True)
print("Downloading", job_full_path)
temp_path = os.path.join(JOB_PREFIX, "slave.temp")
with ConnectionContext():
@@ -170,7 +170,7 @@ def render_slave(engine, netsettings, threads):
if job.type == netrender.model.JOB_BLENDER:
- job_path = job.files[0].filepath # path of main file
+ job_path = job.files[0].original_path # original path of the first file
main_path, main_file = os.path.split(job_path)
job_full_path = testFile(conn, job.id, slave_id, job.files[0], JOB_PREFIX)